@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2010 Emmanuel Pacaud
+ * Copyright © 2009-2011 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,7 +32,7 @@ typedef void (*ArvFakeCameraFillPattern) (ArvBuffer *buffer, void *fill_pattern_
 					  guint32 exposure_time_us, guint32 gain,
 					  ArvPixelFormat pixel_format);
 
-#define ARV_FAKE_CAMERA_MEMORY_SIZE	0x1000
+#define ARV_FAKE_CAMERA_MEMORY_SIZE	0x10000
 
 /* To keep in sync with arv-fake-camera.xml */
 
@@ -47,6 +47,7 @@ typedef void (*ArvFakeCameraFillPattern) (ArvBuffer *buffer, void *fill_pattern_
 #define ARV_FAKE_CAMERA_REGISTER_BINNING_HORIZONTAL	0x108
 #define ARV_FAKE_CAMERA_REGISTER_BINNING_VERTICAL	0x10c
 #define ARV_FAKE_CAMERA_REGISTER_PIXEL_FORMAT		0x128
+#define ARV_FAKE_CAMERA_REGISTER_TEST			0x1f0
 
 #define ARV_FAKE_CAMERA_SENSOR_WIDTH			2048
 #define ARV_FAKE_CAMERA_SENSOR_HEIGHT			2048
@@ -55,6 +56,7 @@ typedef void (*ArvFakeCameraFillPattern) (ArvBuffer *buffer, void *fill_pattern_
 #define ARV_FAKE_CAMERA_BINNING_HORIZONTAL_DEFAULT	1
 #define ARV_FAKE_CAMERA_BINNING_VERTICAL_DEFAULT	1
 #define ARV_FAKE_CAMERA_PIXEL_FORMAT_DEFAULT		ARV_PIXEL_FORMAT_MONO_8
+#define ARV_FAKE_CAMERA_TEST_REGISTER_DEFAULT		0x12345678
 
 /* Acquisition control */
 
@@ -111,7 +113,8 @@ gboolean	arv_fake_camera_write_register 	(ArvFakeCamera *camera, guint32 address
 
 size_t 		arv_fake_camera_get_payload 		(ArvFakeCamera *camera);
 void 		arv_fake_camera_wait_for_next_frame 	(ArvFakeCamera *camera);
-void		arv_fake_camera_fill_buffer		(ArvFakeCamera *camera, ArvBuffer *buffer);
+void		arv_fake_camera_fill_buffer		(ArvFakeCamera *camera, ArvBuffer *buffer,
+							 guint32 *packet_size);
 
 guint32 	arv_fake_camera_get_acquisition_status 	(ArvFakeCamera *camera);
 GSocketAddress *arv_fake_camera_get_stream_address 	(ArvFakeCamera *camera);
