@@ -79,7 +79,6 @@ _read_memory (ArvGvDeviceIOData *io_data, guint32 address, guint32 size, void *b
 	int count;
 	unsigned int n_retries = 0;
 	gboolean success = FALSE;
-	gboolean error = FALSE;
 
 	answer_size = arv_gvcp_packet_get_read_memory_ack_size (size);
 
@@ -93,7 +92,8 @@ _read_memory (ArvGvDeviceIOData *io_data, guint32 address, guint32 size, void *b
 						      0, &packet_size);
 
 	do {
-		arv_gvcp_packet_set_packet_count (packet, ++io_data->packet_count);
+		io_data->packet_count = arv_gvcp_next_packet_count (io_data->packet_count);
+		arv_gvcp_packet_set_packet_count (packet, io_data->packet_count);
 
 		arv_gvcp_packet_debug (packet, ARV_DEBUG_LEVEL_LOG);
 
@@ -122,13 +122,13 @@ _read_memory (ArvGvDeviceIOData *io_data, guint32 address, guint32 size, void *b
 					memcpy (buffer, arv_gvcp_packet_get_read_memory_ack_data (ack_packet), size);
 					success = TRUE;
 				} else
-					error = TRUE;
+					arv_gvcp_packet_debug (ack_packet, ARV_DEBUG_LEVEL_WARNING);
 			}
 		}
 
 		n_retries++;
 
-	} while (!success && !error && n_retries < io_data->gvcp_n_retries);
+	} while (!success && n_retries < io_data->gvcp_n_retries);
 
 	arv_gvcp_packet_free (packet);
 
@@ -145,7 +145,6 @@ _write_memory (ArvGvDeviceIOData *io_data, guint32 address, guint32 size, void *
 	int count;
 	unsigned int n_retries = 0;
 	gboolean success = FALSE;
-	gboolean error = FALSE;
 
 	g_mutex_lock (io_data->mutex);
 
@@ -157,7 +156,8 @@ _write_memory (ArvGvDeviceIOData *io_data, guint32 address, guint32 size, void *
 	memcpy (arv_gvcp_packet_get_write_memory_cmd_data (packet), buffer, size);
 
 	do {
-		arv_gvcp_packet_set_packet_count (packet, ++io_data->packet_count);
+		io_data->packet_count = arv_gvcp_next_packet_count (io_data->packet_count);
+		arv_gvcp_packet_set_packet_count (packet, io_data->packet_count);
 
 		arv_gvcp_packet_debug (packet, ARV_DEBUG_LEVEL_LOG);
 
@@ -185,13 +185,13 @@ _write_memory (ArvGvDeviceIOData *io_data, guint32 address, guint32 size, void *
 				    packet_count == io_data->packet_count)
 					success = TRUE;
 				else
-					error = TRUE;
+					arv_gvcp_packet_debug (ack_packet, ARV_DEBUG_LEVEL_WARNING);
 			}
 		}
 
 		n_retries++;
 
-	} while (!success && !error && n_retries < io_data->gvcp_n_retries);
+	} while (!success && n_retries < io_data->gvcp_n_retries);
 
 	arv_gvcp_packet_free (packet);
 
@@ -208,14 +208,14 @@ _read_register (ArvGvDeviceIOData *io_data, guint32 address, guint32 *value_plac
 	int count;
 	unsigned int n_retries = 0;
 	gboolean success = FALSE;
-	gboolean error = FALSE;
 
 	g_mutex_lock (io_data->mutex);
 
 	packet = arv_gvcp_packet_new_read_register_cmd (address, 0, &packet_size);
 
 	do {
-		arv_gvcp_packet_set_packet_count (packet, ++io_data->packet_count);
+		io_data->packet_count = arv_gvcp_next_packet_count (io_data->packet_count);
+		arv_gvcp_packet_set_packet_count (packet, io_data->packet_count);
 
 		arv_gvcp_packet_debug (packet, ARV_DEBUG_LEVEL_LOG);
 
@@ -244,13 +244,13 @@ _read_register (ArvGvDeviceIOData *io_data, guint32 address, guint32 *value_plac
 					*value_placeholder = arv_gvcp_packet_get_read_register_ack_value (ack_packet);
 					success = TRUE;
 				} else
-					error = TRUE;
+					arv_gvcp_packet_debug (ack_packet, ARV_DEBUG_LEVEL_WARNING);
 			}
 		}
 
 		n_retries++;
 
-	} while (!success && !error && n_retries < io_data->gvcp_n_retries);
+	} while (!success && n_retries < io_data->gvcp_n_retries);
 
 	arv_gvcp_packet_free (packet);
 
@@ -270,14 +270,14 @@ _write_register (ArvGvDeviceIOData *io_data, guint32 address, guint32 value)
 	int count;
 	unsigned int n_retries = 0;
 	gboolean success = FALSE;
-	gboolean error = FALSE;
 
 	g_mutex_lock (io_data->mutex);
 
 	packet = arv_gvcp_packet_new_write_register_cmd (address, value, io_data->packet_count, &packet_size);
 
 	do {
-		arv_gvcp_packet_set_packet_count (packet, ++io_data->packet_count);
+		io_data->packet_count = arv_gvcp_next_packet_count (io_data->packet_count);
+		arv_gvcp_packet_set_packet_count (packet, io_data->packet_count);
 
 		arv_gvcp_packet_debug (packet, ARV_DEBUG_LEVEL_LOG);
 
@@ -306,13 +306,13 @@ _write_register (ArvGvDeviceIOData *io_data, guint32 address, guint32 value)
 				    packet_count == io_data->packet_count)
 					success = TRUE;
 				else
-					error = TRUE;
+					arv_gvcp_packet_debug (ack_packet, ARV_DEBUG_LEVEL_WARNING);
 			}
 		}
 
 		n_retries++;
 
-	} while (!success && !error && n_retries < io_data->gvcp_n_retries);
+	} while (!success && n_retries < io_data->gvcp_n_retries);
 
 	arv_gvcp_packet_free (packet);
 
@@ -324,6 +324,7 @@ _write_register (ArvGvDeviceIOData *io_data, guint32 address, guint32 value)
 /* Heartbeat thread */
 
 typedef struct {
+	ArvGvDevice *gv_device;
 	ArvGvDeviceIOData *io_data;
 	int period_us;
 	gboolean cancel;
@@ -334,28 +335,51 @@ arv_gv_device_heartbeat_thread (void *data)
 {
 	ArvGvDeviceHeartbeatData *thread_data = data;
 	ArvGvDeviceIOData *io_data = thread_data->io_data;
+	GTimer *timer;
 	guint32 value;
 
+	timer = g_timer_new ();
+
 	do {
 		g_usleep (thread_data->period_us);
 
 		if (io_data->is_controller) {
+			guint counter = 1;
 
 			/* TODO: Instead of reading the control register, Pylon does write the heartbeat
 			 * timeout value, which is interresting, as doing this we could get an error
 			 * ack packet which will indicate we lost the control access. */
 
-			_read_register (io_data, ARV_GVBS_CONTROL_CHANNEL_PRIVILEGE_OFFSET, &value);
-			arv_log_device ("[GvDevice::Heartbeat] (%d)", value);
+			g_timer_start (timer);
 
-			if ((value & (ARV_GVBS_CONTROL_CHANNEL_PRIVILEGE_CONTROL |
-				      ARV_GVBS_CONTROL_CHANNEL_PRIVILEGE_EXCLUSIVE)) == 0) {
-				arv_warning_device ("[GvDevice::Heartbeat] Control access lost");
-				io_data->is_controller = FALSE;
+			while (!_read_register (io_data, ARV_GVBS_CONTROL_CHANNEL_PRIVILEGE_OFFSET, &value) &&
+			       g_timer_elapsed (timer, NULL) < ARV_GV_DEVICE_HEARTBEAT_RETRY_TIMEOUT_S &&
+			       !thread_data->cancel) {
+				g_usleep (ARV_GV_DEVICE_HEARTBEAT_RETRY_DELAY_US);
+				counter++;
 			}
+
+			if (!thread_data->cancel) {
+				arv_log_device ("[GvDevice::Heartbeat] Ack value = %d", value);
+
+				if (counter > 1)
+					arv_log_device ("[GvDevice::Heartbeat] Tried %u times", counter);
+
+				if ((value & (ARV_GVBS_CONTROL_CHANNEL_PRIVILEGE_CONTROL |
+					      ARV_GVBS_CONTROL_CHANNEL_PRIVILEGE_EXCLUSIVE)) == 0) {
+					arv_warning_device ("[GvDevice::Heartbeat] Control access lost");
+
+					arv_device_emit_control_lost_signal (ARV_DEVICE (thread_data->gv_device));
+
+					io_data->is_controller = FALSE;
+				}
+			} else
+				io_data->is_controller = FALSE;
 		}
 	} while (!thread_data->cancel);
 
+	g_timer_destroy (timer);
+
 	return NULL;
 }
 
@@ -383,9 +407,10 @@ arv_gv_device_leave_control (ArvGvDevice *gv_device)
 {
 	gboolean success;
 
+	gv_device->priv->io_data->is_controller = FALSE;
+
 	success = arv_device_write_register (ARV_DEVICE (gv_device),
 					    ARV_GVBS_CONTROL_CHANNEL_PRIVILEGE_OFFSET, 0);
-	gv_device->priv->io_data->is_controller = FALSE;
 
 	return success;
 }
@@ -688,7 +713,7 @@ arv_gv_device_new (GInetAddress *interface_address, GInetAddress *device_address
 	io_data = g_new0 (ArvGvDeviceIOData, 1);
 
 	io_data->mutex = g_mutex_new ();
-	io_data->packet_count = 0;
+	io_data->packet_count = 65300; /* Start near the end of the circular counter */
 
 	io_data->interface_address = g_inet_socket_address_new (interface_address, 0);
 	io_data->device_address = g_inet_socket_address_new (device_address, ARV_GVCP_PORT);
@@ -711,8 +736,9 @@ arv_gv_device_new (GInetAddress *interface_address, GInetAddress *device_address
 	arv_gv_device_take_control (gv_device);
 
 	heartbeat_data = g_new (ArvGvDeviceHeartbeatData, 1);
+	heartbeat_data->gv_device = gv_device;
 	heartbeat_data->io_data = io_data;
-	heartbeat_data->period_us = 1000000;
+	heartbeat_data->period_us = ARV_GV_DEVICE_HEARTBEAT_PERIOD_US;
 	heartbeat_data->cancel = FALSE;
 
 	gv_device->priv->heartbeat_data = heartbeat_data;
