@@ -31,6 +31,9 @@ G_BEGIN_DECLS
 
 #define	ARV_GV_DEVICE_GVCP_N_RETRIES_DEFAULT	5
 #define	ARV_GV_DEVICE_GVCP_TIMEOUT_MS_DEFAULT	500
+#define	ARV_GV_DEVICE_HEARTBEAT_PERIOD_US	1000000
+#define	ARV_GV_DEVICE_HEARTBEAT_RETRY_DELAY_US	10000
+#define	ARV_GV_DEVICE_HEARTBEAT_RETRY_TIMEOUT_S	5.0		/* FIXME */
 
 #define ARV_GV_DEVICE_GVSP_PACKET_SIZE_DEFAULT	1500
 
