@@ -141,6 +141,14 @@ emit_software_trigger (void *abstract_data)
 	return TRUE;
 }
 
+static void
+control_lost_cb (ArvGvDevice *gv_device)
+{
+	g_printf ("Control lost\n");
+
+	cancel = TRUE;
+}
+
 int
 main (int argc, char **argv)
 {
@@ -251,6 +259,9 @@ main (int argc, char **argv)
 			g_signal_connect (stream, "new-buffer", G_CALLBACK (new_buffer_cb), &data);
 			arv_stream_set_emit_signals (stream, TRUE);
 
+			g_signal_connect (arv_camera_get_device (camera), "control-lost",
+					  G_CALLBACK (control_lost_cb), NULL);
+
 			g_timeout_add_seconds (1, periodic_task_cb, &data);
 
 			data.main_loop = g_main_loop_new (NULL, FALSE);
