@@ -1,7 +1,4 @@
 #include <arv.h>
-#ifdef ARAVIS_WITH_CAIRO
-#include <cairo.h>
-#endif
 #include <stdlib.h>
 
 static gboolean cancel = FALSE;
@@ -14,9 +11,6 @@ set_cancel (int signal)
 
 static char *arv_option_camera_name = NULL;
 static char *arv_option_debug_domains = NULL;
-#ifdef ARAVIS_WITH_CAIRO
-static gboolean arv_option_snaphot = FALSE;
-#endif
 static gboolean arv_option_auto_buffer = FALSE;
 static int arv_option_width = -1;
 static int arv_option_height = -1;
@@ -27,10 +21,6 @@ static const GOptionEntry arv_option_entries[] =
 {
 	{ "name",		'n', 0, G_OPTION_ARG_STRING,
 		&arv_option_camera_name,"Camera name", NULL},
-#ifdef ARAVIS_WITH_CAIRO
-	{ "snapshot",		's', 0, G_OPTION_ARG_NONE,
-		&arv_option_snaphot,	"Snapshot", NULL},
-#endif
 	{ "auto",		'a', 0, G_OPTION_ARG_NONE,
 		&arv_option_auto_buffer,	"AutoBufferSize", NULL},
 	{ "width", 		'w', 0, G_OPTION_ARG_INT,
@@ -61,9 +51,6 @@ main (int argc, char **argv)
 	GError *error = NULL;
 	char memory_buffer[100000];
 	int i;
-#ifdef ARAVIS_WITH_CAIRO
-	gboolean snapshot_done = FALSE;
-#endif
 
 	g_thread_init (NULL);
 	g_type_init ();
@@ -194,13 +181,13 @@ main (int argc, char **argv)
 		for (i = 0; i < 30; i++)
 			arv_stream_push_buffer (stream, arv_buffer_new (value, NULL));
 
-		arv_device_read_register (device, ARV_GVBS_FIRST_STREAM_CHANNEL_PORT, &value);
+		arv_device_read_register (device, ARV_GVBS_STREAM_CHANNEL_0_PORT_OFFSET, &value);
 		g_print ("stream port = %d (%d)\n", value, arv_gv_stream_get_port (ARV_GV_STREAM (stream)));
 
 		arv_device_read_memory (device, 0x00014150, 8, memory_buffer);
 		arv_device_read_memory (device, 0x000000e8, 16, memory_buffer);
 		arv_device_read_memory (device,
-					ARV_GVBS_USER_DEFINED_NAME,
+					ARV_GVBS_USER_DEFINED_NAME_OFFSET,
 					ARV_GVBS_USER_DEFINED_NAME_SIZE, memory_buffer);
 
 		node = arv_gc_get_node (genicam, "AcquisitionStart");
@@ -213,30 +200,12 @@ main (int argc, char **argv)
 
 			do  {
 				buffer = arv_stream_pop_buffer (stream);
-				if (buffer != NULL) {
-#ifdef ARAVIS_WITH_CAIRO
-					if (arv_option_snaphot &&
-					    !snapshot_done &&
-					    buffer->status == ARV_BUFFER_STATUS_SUCCESS) {
-						snapshot_done = TRUE;
-
-						cairo_surface_t *surface;
-
-						surface = cairo_image_surface_create_for_data (buffer->data,
-											       CAIRO_FORMAT_A8,
-											       buffer->width,
-											       buffer->height,
-											       buffer->width);
-						cairo_surface_write_to_png (surface, "test.png");
-						cairo_surface_destroy (surface);
-					}
-#endif
+				if (buffer != NULL)
 					arv_stream_push_buffer (stream, buffer);
-				}
 			} while (buffer != NULL);
 		} while (!cancel);
 
-		arv_device_read_register (device, ARV_GVBS_FIRST_STREAM_CHANNEL_PORT, &value);
+		arv_device_read_register (device, ARV_GVBS_STREAM_CHANNEL_0_PORT_OFFSET, &value);
 		g_print ("stream port = %d (%d)\n", value, arv_gv_stream_get_port (ARV_GV_STREAM (stream)));
 
 		arv_stream_get_statistics (stream, &n_processed_buffers, &n_failures, &n_underruns);
